# disckit
An open source utilities library for the disutils bots

> [!WARNING]  
> **Note:** This package exclusively supports **Application Commands only** for the API wrapper [discord.py](https://github.com/Rapptz/discord.py).\
This package may cause unexepected behaviour if used with any other API wrapper or forks of `discord.py`.

![Alt](https://repobeats.axiom.co/api/embed/90c2ae330c90d87026c048335eac0923d31b683f.svg "Repobeats analytics image")
